import { APIClient } from "./ApiClient";

export interface NWFilterChain {
  protocol: string;
  suffix?: string;
}

export interface NWFSAll {
  type: "all";
}

export interface NWFSMac {
  type: "mac";
  src_mac_addr?: string;
  src_mac_mask?: string;
  dst_mac_addr?: string;
  dst_mac_mask?: string;
  comment?: string;
}

// TODO : complete
export type NWFSelector = NWFSAll | NWFSMac;

export interface NWFilterRule {
  action: "drop" | "reject" | "accept" | "return" | "continue";
  direction: "in" | "out" | "inout";
  priority?: number;
  selectors: NWFSelector[];
}

export interface NWFilter {
  name: string;
  chain?: NWFilterChain;
  priority?: number;
  uuid?: string;
  join_filters: string[];
  rules: NWFilterRule[];
}

export function NWFilterURL(n: NWFilter, edit: boolean = false): string {
  return `/nwfilter/${n.uuid}${edit ? "/edit" : ""}`;
}

export class NWFilterApi {
  /**
   * Get the entire list of networks
   */
  static async GetList(): Promise<NWFilter[]> {
    const list: NWFilter[] = (
      await APIClient.exec({
        method: "GET",
        uri: "/nwfilter/list",
      })
    ).data;

    list.sort((a, b) => a.name.localeCompare(b.name));

    return list;
  }
}
